# diin_text
> help library


This file will become your README and also the index of your documentation.

## Install

`pip install diin_text`

## How to use

Fill me in please! Don't forget code examples:

```
1+1
```




    2


